/**
* Contains properties and methods for storing and
* performing calculations on electronic displays.
*/
declare class ScreenCalc {
    private pixelWidth;
    private pixelHeight;
    private diagonalSize;
    constructor(pixelWidth: number, pixelHeight: number, diagonalSize?: number);
    public getPixelWidth(): number;
    public setPixelWidth(pixelWidth: number): void;
    public getPixelHeight(): number;
    public setPixelHeight(pixelHeight: number): void;
    /** Returns the diagonal size of the display */
    public getDiagonalSize(): number;
    public setDiagonalSize(diagonalSize: number): void;
    /**
    * Returns the number of pixels per unit in the display
    * (will be ppi if units are in, or ppcm if units are cm)
    */
    public getPixelDensity(): number;
    /**
    * Set the display's diagonal size from its pixel density (pixels per unit)
    */
    public setPixelDensity(ppu: number): void;
    /** Returns the physical width of the display */
    public getPhysicalWidth(): number;
    /** Returns the physical height of the display */
    public getPhysicalHeight(): number;
    /** Returns the area of the display in square units */
    public getArea(): number;
    /** Returns the total number of pixels in the screen */
    public getPixelCount(): number;
    /**
    * Returns the screen's width divided by its height.
    * For example, the ratio of a 1920x1080 display would
    * be 1.78 when rounded to two decimal places.
    */
    public getRatio(): number;
    /**
    * Returns a screen's ratio as a simplified string.
    * For example, a 1920x1080 display would return 16:9
    */
    public getStringRatio(): string;
    /** Returns true if the specified value is a positive integer */
    static isPositiveInt(val: any): boolean;
    /** Returns true if the value is a positive number */
    static isPositiveNum(val: any): boolean;
}
export = ScreenCalc;
